@@ -8,7 +8,6 @@
 
 #include "addlocationmodel.h"
 
-#include "kclockformat.h"
 #include "savedlocationsmodel.h"
 #include "utilmodel.h"
 
@@ -17,7 +16,6 @@
 #include <KSharedConfig>
 
 #include <QDebug>
-#include <QTimeZone>
 
 const QString TZ_CFG_GROUP = QStringLiteral("Timezones");
 
@@ -135,10 +133,6 @@ void AddLocationSearchModel::addLocation(int index)
 
 bool AddLocationSearchModel::lessThan(const QModelIndex &left, const QModelIndex &right) const
 {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     return QVariant::compare(sourceModel()->data(left, AddLocationModel::CityRole), sourceModel()->data(right, AddLocationModel::CityRole))
         == QPartialOrdering::Less;
-#else
-    return sourceModel()->data(left, AddLocationModel::CityRole) < sourceModel()->data(right, AddLocationModel::CityRole);
-#endif
 }
